==> haskell-configurator-0.3.0.0-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-13IFBMY0Q2zCbHY37sD9nY
key: configurator-0.3.0.0-13IFBMY0Q2zCbHY37sD9nY
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
abi: 7bff21e4d2d59eba5e39adcd801c99c2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-13IFBMY0Q2zCbHY37sD9nY
depends:
    attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH base-4.10.1.0
    bytestring-0.10.8.2 directory-1.3.0.2
    hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
abi-depends: attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH=1e5250700950658eff033f7537304029
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy=0960747f6d33db66637f40f842025f18
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=b12cdae8ac228affcce9703d4cef3dce
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-0.3.0.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-5WQc6GMPthA3lslEE6kdG1
key: configurator-0.3.0.0-5WQc6GMPthA3lslEE6kdG1
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
abi: e2792b8422cfc0faf70950fed1eff1c8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-5WQc6GMPthA3lslEE6kdG1
depends:
    attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT base-4.10.1.0
    bytestring-0.10.8.2 directory-1.3.0.2
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
abi-depends: attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT=969f51e12ac15d411e4c04135fb32864
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=087c0712ec00d90dbe506989d07212a2
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=8c4e411a71da620d885f29fab6ff998d
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
